;******************************************************************************************************
;* File Name          : OPA_INIT.INC
;* Author             : MASSES CHIP
;* Version            : V1.00
;* Date               : 2019/09/01
;******************************************************************************************************
;
;OPA初始化
;
;******************************************************************************************************
;///////////////////// OPA0C0控制寄存器各位定义////////////////////////////////////////////////////////
;******************************************************************************************************
;//Bit 7 OPA0EN:运放使能控制位
;//1 = 使能运放
;//0 = 关闭运放
;//Bit 6 OPA0O:运放输出位(只读）
;//1 = OPAP脚输入电压大于OPAN脚
;//0 = OPAP脚输入电压小于OPAN脚
;//Bit[5:3]OPA0NS[2:0]:运放反相输入信号选择位
;//001	输入信号选择OPA0N
;//010	输入信号选择GND
;//011	输入信号选择VDD/2
;//100	输入信号选择VREF
;//101	输入信号选择GND
;//Bit[2:0]OPA0PS[2:0]:运放正相输入信号选择位
;//001	输入信号选择OPA0P
;//010	输入信号选择GND
;//011	输入信号选择VDD/2
;//100	输入信号选择VREF
;//101	输入信号选择GND
#define		OPA0EN_1				b'10000000'						;//使能运放
#define   	OPA0EN_0     			b'00000000'						;//关闭运放
#define		OPA0O_1					b'01000000'						;//OPAP脚输入电压大于OPAN脚
#define		OPA0O_0					b'00000000'						;//OPAP脚输入电压小于OPAN脚
#define		OPA0NS_001				b'00001000'						;//输入信号选择OPA0N
#define		OPA0NS_010				b'00010000'						;//输入信号选择GND
#define		OPA0NS_011				b'00011000'						;//输入信号选择VDD/2
#define		OPA0NS_100				b'00100000'						;//输入信号选择VREF
#define		OPA0NS_101				b'00101000'						;//输入信号选择GND
#define		OPA0PS_001				b'00000001'						;//输入信号选择OPA0N
#define		OPA0PS_010				b'00000010'						;//输入信号选择GND
#define		OPA0PS_011				b'00000011'						;//输入信号选择VDD/2
#define		OPA0PS_100				b'00000100'						;//输入信号选择VREF
#define		OPA0PS_101				b'00000101'						;//输入信号选择GND

;******************************************************************************************************
;///////////////////// OPA0C1控制寄存器各位定义////////////////////////////////////////////////////////
;******************************************************************************************************
;//Bit 7 A0ENLO:运放逻辑输出使能
;//1 = 使能运放逻辑输出功能
;//0 = 关闭运放逻辑输出功能
;//Bit 6 OPA0VRC:运放OPAP端信号从端口输出
;//1 = OPAP端信号从端口输出
;//0 = 关闭
;//Bit 5 OPAHIEN:运放功耗选择
;//1 = 大功耗
;//0 = 小功耗
;//Bit 4 OPAOFM:校准模式选择
;//1 = 失调校准模式
;//0 = 正常工作模式
;//Bit[3:0]OPAPOF:校准参数位
#define		A0ENLO_1				b'10000000'						;//使能运放逻辑输出功能					
#define		A0ENLO_0				b'00000000'						;//关闭运放逻辑输出功能						
#define		OPA0VRC_1				b'01000000'						;//OPAP端信号从端口输出			
#define		OPA0VRC_0				b'00000000'						;//关闭		             
#define		OPAHIEN_1				b'00100000'						;//大功耗				
#define		OPAHIEN_0				b'00000000'						;//小功耗					
#define		OPAOFM_1				b'00010000'						;//失调校准模式				
#define		OPAOFM_0				b'00000000'						;//正常工作模式
#define		OPAPOF_0001				b'00000001'											
#define		OPAPOF_0010				b'00000010'	
#define		OPAPOF_0100				b'00000100'						
#define		OPAPOF_1000				b'00001000'	

;******************************************************************************************************
;///////////////////// COPA0C控制寄存器各位定义////////////////////////////////////////////////////////
;******************************************************************************************************
;//Bit 4 OPA0GS:运放内建放大倍数选择
;//1 = 50倍放大
;//0 = 10倍放大
;//Bit 3 A0SW3: 运放通路开关选择
;//1 = 闭合
;//0 = 断开
;//Bit 2 A0SW2: 运放通路开关选择
;//1 = 闭合
;//0 = 断开
;//Bit 1 A0SW1: 运放通路开关选择
;//1 = 闭合
;//0 = 断开
;//Bit 0 A0SW0: 运放通路开关选择
;//1 = 闭合
;//0 = 断开
#define		OPA0GS_1				b'00010000'						;//50倍放大					
#define		OPA0GS_0				b'00000000'						;//10倍放大			             
#define		A0SW3_1					b'00001000'						;//闭合				
#define		A0SW3_0					b'00000000'						;//断开				
#define		A0SW2_1					b'00000100'						;//闭合			
#define		A0SW2_0					b'00000000'						;//断开
#define		A0SW1_1					b'00000010'						;//闭合	
#define		A0SW1_0					b'00000000'						;//断开
#define		A0SW0_1					b'00000001'						;//闭合	
#define		A0SW0_0					b'00000000'						;//断开

;******************************************************************************************************
;///////////////////////////////////// OPA初始化///////////////////////////////////////////////////////
;******************************************************************************************************
;******************************************************************************************************
;///////////////////////////////////// OPA初始化///////////////////////////////////////////////////////
;******************************************************************************************************
;//OPA0校准
;A0SW[3：0]设为【0000】
;OPA0EN使能 A0ENLO使能 OPAOFM使能
;OPAOPF[3：0] 设为【0000】
;读OPA0O的值，
;然后 OPAOPF[3：0] 加一，直至OPA0O的值发生变化。
;如果OPAOPF[3：0]到【1111】时OPA0O仍为0，那校准值就是【1111】
;然后OPAOPF[3：0] 的值保留在寄存器中，
;OPAOFM清零，其他寄存器按应用需要设置
OPA_INIT:
;//1、OPA0校准
CAL_OFFSET_OP0_START:
		MOVIA		OPA0EN_1+OPA0PS_011
		MOVAR		OPA0C0
		MOVIA		A0ENLO_1+OPAHIEN_1+OPAOFM_1
		MOVAR		OPA0C1
		MOVIA		OPA0GS_0+A0SW3_1
		MOVAR		COPA0C
CAL_OFFSET_OP0_LOOP:
		CALL		Delay											;//OPA0O变为1时，此时的OPAOPF[3：0] 为校准值。
		JBTS0		OPA0C0,6
		GOTO		CAL_OFFSET_OP0_END
		INCR		OPA0C1,R
		MOVR		OPA0C1,A
		ANDIA		0X0F
		JCMPAI		0X0F
		GOTO		CAL_OFFSET_OP0_LOOP
CAL_OFFSET_OP0_END:
;//2、IO端口设置
		MOVIA      	b'11100111'								
		MOVAR   	OEA												;//A0N、A0P端口设置
		MOVIA       b'10111111'
		MOVAR       OEB												;//A0X端口设置
;//3、放大器控制寄存器设置			
		MOVIA       OPA0NS_001+OPA0PS_001		 
		MOVAR	    OPA0C0																			
		MOVIA		A0ENLO_0+OPA0VRC_0+OPAHIEN_1+OPAOFM_0				
		MOVAR		OPA0C1		
		MOVIA		OPA0GS_0+A0SW3_1+A0SW2_1			
		MOVAR		COPA0C	
;//4.使能放大器
		BSET		OPA0C0,7
		
		RETURN
;******************************************************************************************************
;///////////////////////////////////////延时程序///////////////////////////////////////////////////////
;****************************************************************************************************** 
Delay:
		MOVIA   	250
		MOVAR   	DelayCnt
Delay_Loop:
		GOTO  		$+1
		GOTO  		$+1
		GOTO  		$+1
		GOTO  		$+1   
		GOTO  		$+1
		GOTO  		$+1
		GOTO  		$+1
		GOTO  		$+1 
		GOTO  		$+1
		;//nop      
		DJZR  		DelayCnt,R
		GOTO    	Delay_Loop
		RETURN
	   

;*********************************END OF FILE***********************************************************		