;*******************(C) COPYRIGHT 2019 Masses-Chip ***********************
;* File Name          : PWM0_INIT.ASM
;* Author             : MASSES CHIP
;* Version            : V1.00
;* Date               : 2019/09/01
;*************************************************************************
;
;PWM0初始化
;
;******************************************************************************************************
;/////////////////////T0CR 控制寄存器各位定义//////////////////////////////////////////////////////////
;******************************************************************************************************
;//Bit 7 TxCR 定时器控制寄存器
;//TCxEN:  TCx模块使能位
;//1 = 使能TCx
;//0 = 关闭TCx
;//Bit[6:5]TCxMOD[1:0]: TCx模式选择位
;//00 = 递增模式
;//01 = 递减模式
;//1X = 中心对齐模式模式
;//Bit[4:3]TCxCKS[1:0]: TCx时钟源选择
;//00	Foscl(低频系统时钟)
;//01	Fosch(高频系统时钟)
;//10	Fcpu
;//11	TC0:(T0cki) TC1:(TK)
;//Bit[2:0]TCxCKPS[2:0]: TCx预分频比选择
;//000	1:1
;//001	1:2
;//010	1:4
;//011	1:8
;//100	1:16
;//101	1:32
;//110	1:64
;//111	1:128
#DEFINE			TC0EN_0          	b'00000000'			;//1 = 使能TCx
#DEFINE         TC0EN_1          	b'10000000'       	;//0 = 关闭TCx
#DEFINE         TC0MOD_00        	b'00000000'       	;//00 = 递增模式
#DEFINE         TC0MOD_01        	b'00100000'       	;//01 = 递减模式
#DEFINE         TC0MOD_10        	b'01000000'       	;//1X = 中心对齐模式模式
#DEFINE         TC0MOD_11        	b'01100000'       	;//1X = 中心对齐模式模式
#DEFINE         TC0CKS_Foscl     	b'00000000'       	;//Foscl(低频系统时钟)
#DEFINE         TC0CKS_Fosch     	b'00001000'       	;//Fosch(高频系统时钟)
#DEFINE         TC0CKS_Fcpu      	b'00010000'       	;//Fcpu
#DEFINE         TC0CKS_TC0CKI    	b'00011000'       	;//T0CKI（TC0）/T1CKI （TC1）
#DEFINE         TC0CKPS_1_1      	b'00000000'       	;//1:1分频
#DEFINE         TC0CKPS_1_2      	b'00000001'       	;//1:2分频
#DEFINE         TC0CKPS_1_4      	b'00000010'       	;//1:4分频
#DEFINE         TC0CKPS_1_8      	b'00000011'       	;//1:8分频
#DEFINE         TC0CKPS_1_16     	b'00000100'       	;//1:16分频
#DEFINE         TC0CKPS_1_32     	b'00000101'       	;//1:32分频
#DEFINE         TC0CKPS_1_64     	b'00000110'       	;//1:64分频
#DEFINE         TC0CKPS_1_128    	b'00000111'       	;//1:128分频
;******************************************************************************************************
;///////////////////// PWM0CR控制寄存器各位定义////////////////////////////////////////////////////////
;******************************************************************************************************
;//Bit 7 PWM0EN:PWM模块使能位
;//1 = 使能PWM
;//0 = 关闭PWM
;//Bit 6 PWM0POE:PWM正相波形输出使能位
;//1 = 端口输出PWM0P波形
;//0 = 端口用作IO
;//Bit 5 PWM0NOE:PWM反相波形输出使能位
;//1 = 端口输出PWM0N波形
;//0 = 端口用作IO
;//Bit 4 PWM0PAS:PWM0P波形有效电平选择
;//1 = PWM0P波形有效电平为低电平
;//0 = PWM0P波形有效电平为高电平
;//Bit 3 PWM0NAS:PWM0N波形有效电平选择
;//1 = PWM0N波形有效电平为高电平
;//0 = PWM0N波形有效电平为低电平
;//Bit 2 PWM0DEN:PWM0死区控制寄存器
;//1 = 使能死区控制
;//0 = 关闭死区控制
;//Bit[1:0]PWM0TBS[1:0]:  PWM0时基选择
;//00	TC0
;//01	TC1
;//10	TC2
;//11	未定义
#DEFINE			PWM0EN_1			b'10000000'			;//使能PWM
#DEFINE   		PWM0EN_0     		b'00000000'			;//关闭PWM
#DEFINE			PWM0POE_1			b'01000000'			;//端口输出PWM0P波形
#DEFINE			PWM0POE_0			b'00000000'			;//端口用作IO
#DEFINE			PWM0NOE_1			b'00100000'			;//端口输出PWM0N波形
#DEFINE			PWM0NOE_0			b'00000000'			;//端口用作IO
#DEFINE			PWM0PAS_1			b'00010000'			;//PWM0P波形有效电平为低电平
#DEFINE			PWM0PAS_0			b'00000000'			;//PWM0P波形有效电平为高电平
#DEFINE			PWM0NAS_1			b'00001000'			;//PWM0N波形有效电平为高电平
#DEFINE			PWM0NAS_0			b'00000000'			;//PWM0N波形有效电平为低电平
#DEFINE			PWM0DEN_1           b'00000100'			;//使能死区控制
#DEFINE			PWM0DEN_0           b'00000000'			;//关闭死区控制
#DEFINE			PWM0TBS_00			b'00000000'			;//TC0
#DEFINE			PWM0TBS_01			b'00000001'			;//TC1
#DEFINE			PWM0TBS_10			b'00000010'			;//TC2
#DEFINE			PWM0TBS_11			b'00000011'			;//未定义

;******************************************************************************************************
;///////////////////// PWMS输出端口控制寄存器各位定义//////////////////////////////////////////////////
;******************************************************************************************************
;//Bit 4 PWM0S:PWM0输出管脚选择
;//1 = PWM0PX/PWM0NX
;//0 = PWM0P/PWM0N
;//Bit[3:2]PWM2S[1:0]:PWM2输出管脚选择
;//00	PWM2P/PWM2N
;//01	PWM2PX/PWM2NX
;//10	PWM2PY/PWM2NY
;//11	PWM2PX+Y/PWM2NX+Y
;//Bit[1:0]PWM1S[1:0]:PWM1输出管脚选择
;//00	PWM1P/PWM1N
;//01	PWM1PX/PWM1NX
;//10	PWM1PY/PWM1NY
;//11	PWM1PX+Y/PWM1NX+Y
#DEFINE			PWM0S_1				b'00010000'			;//1 = PWM0PX/PWM0NX
#DEFINE			PWM0S_0				b'00000000'			;//0 = PWM0P/PWM0N
#DEFINE			PWM2S_00			b'00000000'			;//PWM2P/PWM2N
#DEFINE			PWM2S_01			b'00000100'			;//PWM2PX/PWM2NX
#DEFINE			PWM2S_10			b'00001000'			;//PWM2PY/PWM2NY
#DEFINE			PWM2S_11			b'00001100'			;//PWM2PX+Y/PWM2NX+Y
#DEFINE			PWM1S_00			b'00000000'			;//PWM1P/PWM1N
#DEFINE			PWM1S_01			b'00000001'			;//PWM1PX/PWM1NX
#DEFINE			PWM1S_10			b'00000010'			;//PWM1PY/PWM1NY
#DEFINE			PWM1S_11			b'00000011'			;//PWM1PX+Y/PWM1NX+Y 
;==========================================================================================
;**************************PWM0初始化******************************************************
;==========================================================================================
PWM0_INIT:
;//1、IO端口设置
		MOVIA      	0x01								;//IOB0口输出PWM0波形
		MOVAR   	OEB
;//2、时钟源设置(以TC0为例,使其产生1KHz的波形)			
		MOVIA       TC0MOD_00+TC0CKS_Fosch+TC0CKPS_1_64	;//各模式位的选择 
		MOVAR	    T0CR		               			;//将模式位配置字写入T0CR
		CLRR	   	TC0CH                    			;//将TC0CH清零
		CLRR		TC0CL								;//将TC0CL清零
		MOVIA      	249                       			;//将249写入TC0PRL
		MOVAR	   	TC0PRL                     			;//16MHz/64/(249+1)=1KHz
		CLRR	 	TC0PRH								;//将TC0PRH清零																
;//3、PWM设置				
		MOVIA		PWM0POE_1+PWM0TBS_00				;//PWM时基选择定时器TC0,端口输出PWM0P波形，
		MOVAR		PWM0CR
		MOVIA      	PWM0S_0								;//输出管脚选择PWM0P/PWM0N
		MOVAR      	PWMS 			
		MOVIA		0x00
		MOVAR		PWM0DH
		MOVIA		(249+1)/2							;//产生占空比为50%的PWM波形
		MOVAR		PWM0DL			
;//4、开启PWM0	
		BSET       	T0CR,7				   	   			;//定时器T0开启
		BSET       	PWM0CR,7				   	   		;//PWM0开启			
		RETURN
;*************************END OF FILE*******************************************  		