/*******************(C) COPYRIGHT 2019 Masses-Chip ******************************
* File Name          : TC0_Init.C
* Author             : MASSES CHIP
* Version            : V1.00
* Date               : 2019/09/01
********************************************************************************
*
*TC0定时程序
*
*******************************************************************************/
#include "common.h"
//******************************************************************************************
/////////////////////T0CR 控制寄存器各位定义////////////////////////////////////////////////
//******************************************************************************************
// Bit7  TC0EN: TC0模块使能位
// 1 = 使能TC0
// 0 = 关闭TC0
// Bit [6:5] TC0MOD: TC0模式选择位
// TC0MOD[1:0] TC0 模式选择
// 00 递增模式
// 01 递减模式
// 1X 中心对齐模式
// 中心对齐模式下，TC0MOD0为只读模式，表示目前定时器的状态
// Bit[4:3] TC0CKS: TC0时钟源选择
// TC0CKS[1:0] TC0 时钟源选择
// 00 Foscl(低频系统时钟)
// 01 Fosch(高频系统时钟)
// 10 Fcpu
// 11
// T0cki（TC0）
// T1cki（TC1）
// Bit[2:0] TC0CKPS[2:0]: TC0预分频比选择
// TC0CKPS[2:0] TC0 预分频比
// 000 1:1
// 001 1:2
// 010 1:4
// 011 1:8
// 100 1:16
// 101 1:32
// 110 1:64
// 111 1:128
#define				TC0EN_1					Bin(10000000)				//使能TC0
#define				TC0EN_0					Bin(00000000)				//关闭ADC
#define				TC0MOD_0				Bin(00000000)				//递增模式
#define				TC0MOD_1				Bin(00100000)				//递减模式
#define				TC0MOD_2				Bin(01000000)				//中心对齐模式
#define				TC0MOD_3				Bin(01100000)				//中心对齐模式
#define				TC0CKS_Foscl			Bin(00000000)				//Foscl(低频系统时钟)
#define				TC0CKS_Fosch			Bin(00001000)				//Fosch(高频系统时钟)
#define				TC0CKS_Fcpu				Bin(00010000)				//Fcpu
#define				TC0CKS_T0CKI			Bin(00011000)				//T0cki（TC0）// T1cki（TC1）
#define				TC0CKPS_1_1				Bin(00000000)				//预分频比 1:1
#define				TC0CKPS_1_2				Bin(00000001)				//预分频比 1:2
#define				TC0CKPS_1_4				Bin(00000010)				//预分频比 1:4
#define				TC0CKPS_1_8				Bin(00000011)				//预分频比 1:8
#define				TC0CKPS_1_16			Bin(00000100)				//预分频比 1:16
#define				TC0CKPS_1_32			Bin(00000101)				//预分频比 1:32
#define				TC0CKPS_1_64			Bin(00000110)				//预分频比 1:64
#define				TC0CKPS_1_128			Bin(00000111)				//预分频比 1:128
//******************************************************************************************
//***********************TC0定时程序********************************************************
//******************************************************************************************
void TC0_Init(void)
{
//1、时钟源设置(以TC0为例,使其产生1ms的波形)
	T0CR =  (unsigned char) (TC0MOD_0 + TC0CKS_Fosch + TC0CKPS_1_16);	//定时器T0，选择高频，16位模式，频分比为1:16
//2、清零计数寄存器    
	TC0CH = 0x00;
    TC0CL = 0x00;															   
//3、配置自动加载计数器	(16M/16T=1us*(999+1)=1ms)	
	TC0PRH = 0x03;																
	TC0PRL = 0xE7;
//3、开启定时器TC0中断	
	TC0IF = 0;															//TC0中断标志清零
	TC0EN = 1;															//清中断标志位
	TC0IE = 1;															//使能TC0溢出中断
	GIE  =  1;															//总中断使能
}
/*********************************END OF FILE**********************************************/ 