;*******************(C) COPYRIGHT 2019 Masses-Chip *****************************************
;* File Name          : TC2G_INIT.INC
;* Author             : MASSES  CHIP
;* Version            : V1.00
;* Date               : 2019/09/01
;*******************************************************************************************
;*******************************************************************************************
;
;TC2G初始化
;
;********************************************************************************************
;//******************************************************************************************
;///////////////////// T0CR控制寄存器各位定义 ///////////////////////////////////////////////
;//******************************************************************************************

;// Bit7  TC0EN: TC0模块使能位
;// 1 = 使能TC0
;// 0 = 关闭TC0
;// Bit [6:5] TC0MOD: TC0模式选择位
;// TC0MOD[1:0] TC0 模式选择
;// 00 递增模式
;// 01 递减模式
;// 1X 中心对齐模式
;// 中心对齐模式下，TC0MOD0为只读模式，表示目前定时器的状态
;// Bit[4:3] TC0CKS: TC0时钟源选择
;// TC0CKS[1:0] TC0 时钟源选择
;// 00 Foscl(低频系统时钟)
;// 01 Fosch(高频系统时钟)
;// 10 Fcpu
;// 11
;// T0cki（TC0）
;// T1cki（TC1）
;// Bit[2:0] TC0CKPS[2:0]: TC0预分频比选择
;// TC0CKPS[2:0] TC0 预分频比
;// 000 1:1
;// 001 1:2
;// 010 1:4
;// 011 1:8
;// 100 1:16
;// 101 1:32
;// 110 1:64
;// 111 1:128
#define				TC0EN_1					b'10000000'				;//使能TC0
#define				TC0EN_0					b'00000000'				;//关闭ADC
#define				TC0MOD_0				b'00000000'				;//递增模式
#define				TC0MOD_1				b'00100000'				;//递减模式
#define				TC0MOD_2				b'01000000'				;//中心对齐模式
#define				TC0MOD_3				b'01100000'				;//中心对齐模式
#define				TC0CKS_Foscl			b'00000000'				;//Foscl(低频系统时钟)
#define				TC0CKS_Fosch			b'00001000'				;//Fosch(高频系统时钟)
#define				TC0CKS_Fcpu				b'00010000'				;//Fcpu
#define				TC0CKS_T0CKI			b'00011000'				;//T0cki（TC0）// T1cki（TC1）
#define				TC0CKPS_1_1				b'00000000'				;//预分频比 1:1
#define				TC0CKPS_1_2				b'00000001'				;//预分频比 1:2
#define				TC0CKPS_1_4				b'00000010'				;//预分频比 1:4
#define				TC0CKPS_1_8				b'00000011'				;//预分频比 1:8
#define				TC0CKPS_1_16			b'00000100'				;//预分频比 1:16
#define				TC0CKPS_1_32			b'00000101'				;//预分频比 1:32
#define				TC0CKPS_1_64			b'00000110'				;//预分频比 1:64
#define				TC0CKPS_1_128			b'00000111'				;//预分频比 1:128

;//******************************************************************************************
;///////////////////// T2CR控制寄存器各位定义 ///////////////////////////////////////////////
;//******************************************************************************************

;// Bit7  TC2EN: TC2模块使能位
;// 1 = 使能TC2
;// 0 = 关闭TC2
;// Bit [6:5] TC2MOD: TC2模式选择位
;// TC2MOD[1:0] TC2 模式选择
;// 00 递增模式
;// 01 递减模式
;// 1X 中心对齐模式
;// 中心对齐模式下，TC2MOD0为只读模式，表示目前定时器的状态
;// Bit[4:3] TC2CKS: TC2时钟源选择
;// TC2CKS[1:0] TC2 时钟源选择
;// 00 Foscl(低频系统时钟)
;// 01 Fosch(高频系统时钟)
;// 10 Fcpu
;// 11
;// T0cki（TC2）
;// T1cki（TC1）
;// Bit[2:0] TC2CKPS[2:0]: TC2预分频比选择
;// TC2CKPS[2:0] TC2 预分频比
;// 000 1:1
;// 001 1:2
;// 010 1:4
;// 011 1:8
;// 100 1:16
;// 101 1:32
;// 110 1:64
;// 111 1:128
#define				TC2EN_1					b'10000000'				;//使能TC2
#define				TC2EN_0					b'00000000'				;//关闭ADC
#define				TC2MOD_0				b'00000000'				;//递增模式
#define				TC2MOD_1				b'00100000'				;//递减模式
#define				TC2MOD_2				b'01000000'				;//中心对齐模式
#define				TC2MOD_3				b'01100000'				;//中心对齐模式
#define				TC2CKS_Foscl			b'00000000'				;//Foscl(低频系统时钟)
#define				TC2CKS_Fosch			b'00001000'				;//Fosch(高频系统时钟)
#define				TC2CKS_Fcpu				b'00010000'				;//Fcpu
#define				TC2CKS_T0CKI			b'00011000'				;//T0cki（TC2）// T1cki（TC1）
#define				TC2CKPS_1_1				b'00000000'				;//预分频比 1:1
#define				TC2CKPS_1_2				b'00000001'				;//预分频比 1:2
#define				TC2CKPS_1_4				b'00000010'				;//预分频比 1:4
#define				TC2CKPS_1_8				b'00000011'				;//预分频比 1:8
#define				TC2CKPS_1_16			b'00000100'				;//预分频比 1:16
#define				TC2CKPS_1_32			b'00000101'				;//预分频比 1:32
#define				TC2CKPS_1_64			b'00000110'				;//预分频比 1:64
#define				TC2CKPS_1_128			b'00000111'				;//预分频比 1:128

;//******************************************************************************************
;///////////////////// T2GCR控制寄存器各位定义 //////////////////////////////////////////////
;//******************************************************************************************
;// Bit 7 		TC2GEN:  TC2门控模式使能位
;// 1 = 使能门控功能
;// 0 = 关闭门控功能，TC2是否计数仅受TC2EN控制
;// Bit 6 		TC2GO:  启动门控控制位
;// 1 = 启动门控
;// 0 = 完成门控计数，自动清零
;// Bit[3:2] 		TC2GS[1:0]:  TC2门控源选择位
;// TC2GS[1:0]	TC2门控选择
;// 00		TC0溢出周期（支持上升沿到上升沿模式）
;// 01		RFC时钟RFCI
;// 10		T2G0
;// 11		T2G1
;// Bit[1:0] 		TC2GM[1:0]:  TC2门控模式选择位
;// TC2GM[1:0]	TC2门控模式选择
;// 00	上升沿到下降沿
;// 01	下降沿到上升沿
;// 10	上升沿到上升沿
;// 11	下降沿到下降沿
#define				TC2GEN_1				b'10000000'				;//使能门控功能
#define				TC2GEN_0				b'00000000'				;//关闭门控功能，TC2是否计数仅受TC2EN控制
#define				TC2GO_1					b'01000000'				;//启动门控
#define				TC2GO_0					b'00000000'				;//完成门控计数，自动清零
#define				TC2GS_TC0				b'00000000'				;//TC0 溢出周期（支持上升沿到上升沿模式）
#define				TC2GS_RFCI				b'00000100'				;//RFC 时钟 RFCI
#define				TC2GS_T2G0				b'00001000'				;// T2G0
#define				TC2GS_T2G1				b'00001100'				;// T2G1
#define				TC2GM_00				b'00000000'				;//上升沿到下降沿
#define				TC2GM_01				b'00000001'				;//下降沿到上升沿
#define				TC2GM_10				b'00000010'				;//上升沿到上升沿
#define				TC2GM_11				b'00000011'				;//下降沿到下降沿

;**********************************************************************************************
;====================================== TC2G定时程序 ===========================================
;**********************************************************************************************	
TC2G_Init:
;//1、时钟源设置(以TC0为门控信号为例,使得TC2计数)
			MOVIA		TC0MOD_0+TC0CKS_Fosch+TC0CKPS_1_16   		;//定时器T0，选择高频，16位模式，频分比为1:16
			MOVAR		T0CR
			MOVIA		TC2MOD_0+TC2CKS_Fosch+TC2CKPS_1_16   		;//定时器T0，选择高频，16位模式，频分比为1:16
			MOVAR		T2CR
			MOVIA		TC2GEN_1+TC2GS_TC0+TC2GM_10			 		;//TC0 溢出周期 上升沿到上升沿
			MOVAR		T2GCR	
;//2、清零计数寄存器
			CLRR		TC0CL										;//将TC0CL清零
			CLRR	    TC0CH       								;//将TC0CH清零
			CLRR		TC2CL										;//将TC2CL清零
			CLRR	    TC2CH       								;//将TC2CH清零
;//3、配置自动加载计数器	(16M/16T=1us*(999+1)=1ms)		
			MOVIA     	0x03       			
			MOVAR	   	TC0PRH       		
			MOVIA     	0xE7       		
			MOVAR	   	TC0PRL 
			MOVIA     	0x03       			
			MOVAR	   	TC2PRH       		
			MOVIA     	0xE7       		
			MOVAR	   	TC2PRL 
;//4、使能TC2,开启TC2中断   
			BSET		T2GCR,6			
			BSET     	T0CR,7         								;//使能TC0
			BSET		T2CR,7         								;//使能TC2
            BCLR		INTF0,TC2GIF        						;//TC2G门控中断标志清零
			BSET		INTCR0,TC2GIE       						;//使能TC2门控中断
			BSET		OPTION,GIE	
			RETURN

;*******************************************END OF FILE************************************************