/*******************(C) COPYRIGHT 2019 Masses-Chip ******************************
* File Name          : TC2G_Init.C
* Author             : MASSES CHIP
* Version            : V1.00
* Date               : 2019/09/01
********************************************************************************
*
*TC2G初始化程序
*
*******************************************************************************/
#include "common.h"
//******************************************************************************************
/////////////////////T0CR 控制寄存器各位定义////////////////////////////////////////////////
//******************************************************************************************
// Bit7  TC0EN: TC0模块使能位
// 1 = 使能TC0
// 0 = 关闭TC0
// Bit [6:5] TC0MOD: TC0模式选择位
// TC0MOD[1:0] TC0 模式选择
// 00 递增模式
// 01 递减模式
// 1X 中心对齐模式
// 中心对齐模式下，TC0MOD0为只读模式，表示目前定时器的状态
// Bit[4:3] TC0CKS: TC0时钟源选择
// TC0CKS[1:0] TC0 时钟源选择
// 00 Foscl(低频系统时钟)
// 01 Fosch(高频系统时钟)
// 10 Fcpu
// 11
// T0cki（TC0）
// T1cki（TC1）
// Bit[2:0] TC0CKPS[2:0]: TC0预分频比选择
// TC0CKPS[2:0] TC0 预分频比
// 000 1:1
// 001 1:2
// 010 1:4
// 011 1:8
// 100 1:16
// 101 1:32
// 110 1:64
// 111 1:128
#define				TC0EN_1					Bin(10000000)				//使能TC0
#define				TC0EN_0					Bin(00000000)				//关闭ADC
#define				TC0MOD_0				Bin(00000000)				//递增模式
#define				TC0MOD_1				Bin(00100000)				//递减模式
#define				TC0MOD_2				Bin(01000000)				//中心对齐模式
#define				TC0MOD_3				Bin(01100000)				//中心对齐模式
#define				TC0CKS_Foscl			Bin(00000000)				//Foscl(低频系统时钟)
#define				TC0CKS_Fosch			Bin(00001000)				//Fosch(高频系统时钟)
#define				TC0CKS_Fcpu				Bin(00010000)				//Fcpu
#define				TC0CKS_T0CKI			Bin(00011000)				//T0cki（TC0）// T1cki（TC1）
#define				TC0CKPS_1_1				Bin(00000000)				//预分频比 1:1
#define				TC0CKPS_1_2				Bin(00000001)				//预分频比 1:2
#define				TC0CKPS_1_4				Bin(00000010)				//预分频比 1:4
#define				TC0CKPS_1_8				Bin(00000011)				//预分频比 1:8
#define				TC0CKPS_1_16			Bin(00000100)				//预分频比 1:16
#define				TC0CKPS_1_32			Bin(00000101)				//预分频比 1:32
#define				TC0CKPS_1_64			Bin(00000110)				//预分频比 1:64
#define				TC0CKPS_1_128			Bin(00000111)				//预分频比 1:128
//******************************************************************************************
/////////////////////T2CR 控制寄存器各位定义////////////////////////////////////////////////
//******************************************************************************************
// Bit7  TC2EN: TC2模块使能位
// 1 = 使能TC2
// 0 = 关闭TC2
// Bit [6:5] TC2MOD: TC2模式选择位
// TC2MOD[1:0] TC2 模式选择
// 00 递增模式
// 01 递减模式
// 1X 中心对齐模式
// 中心对齐模式下，TC2MOD0为只读模式，表示目前定时器的状态
// Bit[4:3] TC2CKS: TC2时钟源选择
// TC2CKS[1:0] TC2 时钟源选择
// 00 Foscl(低频系统时钟)
// 01 Fosch(高频系统时钟)
// 10 Fcpu
// 11
// T0cki（TC2）
// T1cki（TC1）
// Bit[2:0] TC2CKPS[2:0]: TC2预分频比选择
// TC2CKPS[2:0] TC2 预分频比
// 000 1:1
// 001 1:2
// 010 1:4
// 011 1:8
// 100 1:16
// 101 1:32
// 110 1:64
// 111 1:128
#define				TC2EN_1					Bin(10000000)				//使能TC2
#define				TC2EN_0					Bin(00000000)				//关闭ADC
#define				TC2MOD_0				Bin(00000000)				//递增模式
#define				TC2MOD_1				Bin(00100000)				//递减模式
#define				TC2MOD_2				Bin(01000000)				//中心对齐模式
#define				TC2MOD_3				Bin(01100000)				//中心对齐模式
#define				TC2CKS_Foscl			Bin(00000000)				//Foscl(低频系统时钟)
#define				TC2CKS_Fosch			Bin(00001000)				//Fosch(高频系统时钟)
#define				TC2CKS_Fcpu				Bin(00010000)				//Fcpu
#define				TC2CKS_T0CKI			Bin(00011000)				//T0cki（TC2）// T1cki（TC1）
#define				TC2CKPS_1_1				Bin(00000000)				//预分频比 1:1
#define				TC2CKPS_1_2				Bin(00000001)				//预分频比 1:2
#define				TC2CKPS_1_4				Bin(00000010)				//预分频比 1:4
#define				TC2CKPS_1_8				Bin(00000011)				//预分频比 1:8
#define				TC2CKPS_1_16			Bin(00000100)				//预分频比 1:16
#define				TC2CKPS_1_32			Bin(00000101)				//预分频比 1:32
#define				TC2CKPS_1_64			Bin(00000110)				//预分频比 1:64
#define				TC2CKPS_1_128			Bin(00000111)				//预分频比 1:128

//******************************************************************************************
///////////////////// T2GCR控制寄存器各位定义 //////////////////////////////////////////////
//******************************************************************************************
// Bit 7 		TC2GEN:  TC2门控模式使能位
// 1 = 使能门控功能
// 0 = 关闭门控功能，TC2是否计数仅受TC2EN控制
// Bit 6 		TC2GO:  启动门控控制位
// 1 = 启动门控
// 0 = 完成门控计数，自动清零
// Bit[3:2] 		TC2GS[1:0]:  TC2门控源选择位
// TC2GS[1:0]	TC2门控选择
// 00		TC2溢出周期（支持上升沿到上升沿模式）
// 01		RFC时钟RFCI
// 10		T2G0
// 11		T2G1
// Bit[1:0] 		TC2GM[1:0]:  TC2门控模式选择位
// TC2GM[1:0]	TC2门控模式选择
// 00	上升沿到下降沿
// 01	下降沿到上升沿
// 10	上升沿到上升沿
// 11	下降沿到下降沿
#define				TC2GEN_1				Bin(10000000)				//使能门控功能
#define				TC2GEN_0				Bin(00000000)				//关闭门控功能，TC2是否计数仅受TC2EN控制
#define				TC2GO_1					Bin(01000000)				//启动门控
#define				TC2GO_0					Bin(00000000)				//完成门控计数，自动清零
#define				TC2GS_TC2				Bin(00000000)				//TC2 溢出周期（支持上升沿到上升沿模式）
#define				TC2GS_RFCI				Bin(00000100)				//RFC 时钟 RFCI
#define				TC2GS_T2G0				Bin(00001000)				// T2G0
#define				TC2GS_T2G1				Bin(00001100)				// T2G1
#define				TC2GM_00				Bin(00000000)				//上升沿到下降沿
#define				TC2GM_01				Bin(00000001)				//下降沿到上升沿
#define				TC2GM_10				Bin(00000010)				//上升沿到上升沿
#define				TC2GM_11				Bin(00000011)				//下降沿到下降沿
//******************************************************************************************
//***********************TC2G初始化程序******************************************************
//******************************************************************************************
void TC2G_Init(void)
{
//1、时钟源设置(以TC0为门控信号为例,使得TC2计数)
	T0CR =  (unsigned char) (TC0MOD_0 + TC0CKS_Fosch + TC0CKPS_1_16);	//定时器T0，选择高频，16位模式，频分比为1:16
	T2CR =  (unsigned char) (TC2MOD_0 + TC2CKS_Fosch + TC2CKPS_1_16);	//定时器T2，选择高频，16位模式，频分比为1:16
	T2GCR = (unsigned char) (TC2GEN_1+TC2GS_TC2+TC2GM_10);
//2、清零计数寄存器    
	TC0CH = 0x00;														//将TC0CL清零
    TC0CL = 0x00;														//将TC0CH清零
	TC2CH = 0x00;														//将TC2CL清零
    TC2CL = 0x00;														//将TC2CH清零
//3、配置自动加载计数器	(16M/16T=1us*(999+1)=1ms)	
	TC0PRH = 0x03;																
	TC0PRL = 0xE7;
	TC2PRH = 0x03;																
	TC2PRL = 0xE7;
//4、使能TC0,开启TC2G中断
	TC2GO = 1;
	TC0EN = 1;
	TC2EN = 1;
	TC2GIF = 0;															//TC2G门控中断标志清零
	TC2GIE = 1;															//使能TC2G门控中断
	GIE  =  1;															//总中断使能
}
/*********************************END OF FILE**********************************************/ 